==> binnie-mods-1.12-2.2.0.7-sources.jar: binnie/genetics/integration/jei/database/DatabaseRecipeMaker.java <==
package binnie.genetics.integration.jei.database;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.item.ItemStack;

import net.minecraftforge.oredict.OreDictionary;

import binnie.genetics.Genetics;
import binnie.genetics.integration.jei.GeneticsJeiPlugin;
import binnie.genetics.item.GeneticsItems;
import binnie.genetics.item.ModuleItems;
import mezz.jei.api.recipe.IStackHelper;

public class DatabaseRecipeMaker {
	public static List<DatabaseRecipeWrapper> create() {
		List<DatabaseRecipeWrapper> recipes = new ArrayList<>();
		ModuleItems items = Genetics.items();

		{
			ItemStack emptySerum = GeneticsItems.EMPTY_SERUM.get(1);
			ItemStack resultSerum = new ItemStack(items.itemSerum, 1, OreDictionary.WILDCARD_VALUE);
			IStackHelper stackHelper = GeneticsJeiPlugin.jeiHelpers.getStackHelper();
			List<ItemStack> subtypes = stackHelper.toItemStackList(resultSerum);
			List<ItemStack> resultSerums = new ArrayList<>();
			for (ItemStack subtype : subtypes) {
				subtype = subtype.func_77946_l();
				subtype.func_77964_b(subtype.func_77958_k());
				resultSerums.add(subtype);
			}
			recipes.add(new DatabaseRecipeWrapper(emptySerum, resultSerums));
		}

		{
			ItemStack emptySerumArray = GeneticsItems.EMPTY_GENOME.get(1);
			ItemStack resultSerumArray = new ItemStack(items.itemSerumArray, 1, OreDictionary.WILDCARD_VALUE);
			IStackHelper stackHelper = GeneticsJeiPlugin.jeiHelpers.getStackHelper();
			List<ItemStack> subtypes = stackHelper.toItemStackList(resultSerumArray);
			List<ItemStack> resultSerumArrays = new ArrayList<>();
			for (ItemStack subtype : subtypes) {
				subtype = subtype.func_77946_l();
				subtype.func_77964_b(subtype.func_77958_k());
				resultSerumArrays.add(subtype);
			}
			recipes.add(new DatabaseRecipeWrapper(emptySerumArray, resultSerumArrays));
		}

		return recipes;
	}
}

==> binnie-mods-1.12.2-2.5.1.192-sources.jar: binnie/genetics/integration/jei/database/DatabaseRecipeMaker.java <==
package binnie.genetics.integration.jei.database;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.item.ItemStack;

import net.minecraftforge.oredict.OreDictionary;

import binnie.genetics.integration.jei.GeneticsJeiPlugin;
import binnie.genetics.item.GeneticsItems;
import binnie.genetics.modules.ModuleCore;

import mezz.jei.api.recipe.IStackHelper;

public class DatabaseRecipeMaker {
	public static List<DatabaseRecipeWrapper> create() {
		List<DatabaseRecipeWrapper> recipes = new ArrayList<>();

		{
			ItemStack emptySerum = GeneticsItems.EMPTY_SERUM.get(1);
			ItemStack resultSerum = new ItemStack(ModuleCore.itemSerum, 1, OreDictionary.WILDCARD_VALUE);
			IStackHelper stackHelper = GeneticsJeiPlugin.jeiHelpers.getStackHelper();
			List<ItemStack> subtypes = stackHelper.toItemStackList(resultSerum);
			List<ItemStack> resultSerums = new ArrayList<>();
			for (ItemStack subtype : subtypes) {
				subtype = subtype.copy();
				subtype.setItemDamage(subtype.getMaxDamage());
				resultSerums.add(subtype);
			}
			recipes.add(new DatabaseRecipeWrapper(emptySerum, resultSerums));
		}

		{
			ItemStack emptySerumArray = GeneticsItems.EMPTY_GENOME.get(1);
			ItemStack resultSerumArray = new ItemStack(ModuleCore.itemSerumArray, 1, OreDictionary.WILDCARD_VALUE);
			IStackHelper stackHelper = GeneticsJeiPlugin.jeiHelpers.getStackHelper();
			List<ItemStack> subtypes = stackHelper.toItemStackList(resultSerumArray);
			List<ItemStack> resultSerumArrays = new ArrayList<>();
			for (ItemStack subtype : subtypes) {
				subtype = subtype.copy();
				subtype.setItemDamage(subtype.getMaxDamage());
				resultSerumArrays.add(subtype);
			}
			recipes.add(new DatabaseRecipeWrapper(emptySerumArray, resultSerumArrays));
		}

		return recipes;
	}
}
